@@ -114,9 +114,71 @@ fn excel_date_xls() {
     assert_eq!(got, expected);
 }
 
+#[test]
+fn excel_date_xls_dateformat() {
+    let wrk = Workdir::new("excel_date_xls_dateformat");
+
+    let xls_file = wrk.load_test_file("excel-xls.xls");
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg("--sheet")
+        .arg("date test")
+        .args(["--date-format", "%+"])
+        .arg(xls_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["date_col", "num_col", "col_Petsa", "just another col"],
+        svec!["2001-12-25", "1", "33423", "foo"],
+        // the date format only applies to this one row
+        svec!["2001-09-11 08:30:00", "3", "44202", "bar"],
+        svec![
+            "This is not a date and will be passed through",
+            "5",
+            "37145",
+            "was"
+        ],
+        svec!["1970-01-01", "7", "39834", "here"],
+        svec!["1989-12-31", "11", "42461", "42"],
+    ];
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn excel_date_xlsx_date_format() {
+    let wrk = Workdir::new("excel_date_xlsx_date_format");
+
+    let xlsx_file = wrk.load_test_file("excel-xlsx.xlsx");
+
+    let mut cmd = wrk.command("excel");
+    cmd.arg("--sheet")
+        .arg("date_test")
+        .args(["--date-format", "%a %Y-%m-%d %H:%M:%S"])
+        .arg(xlsx_file);
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["date", "plaincol"],
+        svec![
+            "1980-12-25",
+            "it will still parse the dates below as date even if plaincol is not in the default \
+             --dates-whitelist because the cell format was set to date"
+        ],
+        svec!["Tue 2001-09-11 08:30:00", "2001-09-11"],
+        svec!["not a date", "Tue 2001-09-11 08:30:00"],
+        svec![
+            "Wednesday, Mar-14-2012",
+            "the date below is not parsed as a date coz we didn't explicitly set the cell format \
+             to a date format and \"plaincol\" is not in the --dates-whitelist"
+        ],
+        svec!["2001-09-11", "9/11/01 8:30 am"],
+    ];
+    assert_eq!(got, expected);
+}
+
 #[test]
 fn excel_date_xlsx() {
-    let wrk = Workdir::new("excel_date_xlsx");
+    let wrk = Workdir::new("excel_date_xls");
 
     let xlsx_file = wrk.load_test_file("excel-xlsx.xlsx");
 
