@@ -71,6 +71,8 @@ mod test_index;
 mod test_input;
 #[cfg(any(feature = "full", feature = "lite"))]
 mod test_join;
+#[cfg(all(feature = "full", feature = "polars"))]
+mod test_joinp;
 #[cfg(any(feature = "full", feature = "lite"))]
 mod test_jsonl;
 #[cfg(feature = "luau")]
